import CardProperty from "@/components/CardProperty";
import HeroImage from "@/components/HeroImage";
import Pagination from "@/components/Pagination";
import { CardPropertyData } from "@/schema/property";
import { getDefaultMetadata } from "@/utils/metadata";
import { Metadata } from "next";

const metaDesc = "Explore the latest properties on the Dynamic Realty.";

export async function generateMetadata(): Promise<Metadata> {
  const metadata = await getDefaultMetadata();
  metadata.title = `Listings For Rent - ${metadata.openGraph?.siteName}`;
  metadata.description = metaDesc;

  return metadata;
}

const propertiesData: CardPropertyData[] = [
  {
    id: 1,
    title: "401 Biscayne Boulevard, Miami",
    slug: "401-biscayne-boulevard",
    images: [
      { url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" },
      { url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" },
      { url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" },
    ],
    price: 5000,
    propertyType: "rent",
    posted_at: "",
    area: 480,
    bathrooms_count: 2,
    bedrooms_count: 2,
    is_available: true,
  },
  {
    id: 2,
    title: "402 Biscayne Boulevard, Miami",
    slug: "402-biscayne-boulevard",
    images: [{ url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" }],
    price: 5000,
    propertyType: "rent",
    posted_at: "",
    area: 480,
    bathrooms_count: 2,
    bedrooms_count: 2,
    is_available: true,
  },
  {
    id: 3,
    title: "403 Biscayne Boulevard, Miami",
    slug: "403-biscayne-boulevard",
    images: [{ url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" }],
    price: 5000,
    propertyType: "rent",
    posted_at: "",
    area: 480,
    bathrooms_count: 2,
    bedrooms_count: 2,
    is_available: true,
  },
  {
    id: 4,
    title: "404 Biscayne Boulevard, Miami",
    slug: "404-biscayne-boulevard",
    images: [{ url: "/images/featured-properties-01-480x287.jpg", alt: "biscayne boulevard" }],
    price: 5000,
    propertyType: "rent",
    posted_at: "",
    area: 480,
    bathrooms_count: 2,
    bedrooms_count: 2,
    is_available: true,
  },
];

export default function ListingsForRent() {
  return (
    <>
      <HeroImage title="Listings For Rent" />

      <section className="section section-md bg-gray-12">
        <div className="container">
          <div className="row row-50">
            <div className="col-lg-7 col-xl-8">
              <div className="row row-30">
                <div className="col-12">
                  <ul className="block-info-1">
                    <li>
                      <div className="form-wrap-group-1">
                        <div className="form-wrap">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Publication Date"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="2">Monday</option>
                            <option value="3">Tuesday</option>
                            <option value="4">Wednesday</option>
                            <option value="5">Thursday</option>
                            <option value="6">Friday</option>
                            <option value="7">Saturday</option>
                            <option value="8">Sunday</option>
                          </select>
                        </div>
                        <div className="form-wrap">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Price Low to High"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="1">Price Low to High</option>
                            <option value="2">Price High to Low</option>
                            <option value="3">Most Popular</option>
                            <option value="4">Top Rated</option>
                            <option value="5">Best Sellers</option>
                          </select>
                        </div>
                      </div>
                    </li>
                  </ul>
                </div>
                <div className="col-12">
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    {propertiesData.map((p) => (
                      <CardProperty key={p.id} data={p} />
                    ))}
                  </div>
                </div>
                <div className="col-12">
                  {/* <ul className="pagination-custom">
                    <li>
                      <a className="active" href="#">
                        1
                      </a>
                    </li>
                    <li>
                      <a href="#">2</a>
                    </li>
                  </ul> */}
                  <Pagination hasNextPage={true} hasPreviousPage={true} totalPages={10} page={3} />
                </div>
              </div>
            </div>
            <div className="col-lg-5 col-xl-4">
              <div className="row row-50">
                <div className="col-md-6 col-lg-12">
                  <div className="block-info">
                    <h3>Find Your Property</h3>
                    <form
                      className="rd-mailform form-select"
                      data-form-output="form-output-global"
                      data-form-type="contact"
                      method="post"
                      action="bat/rd-mailform.php"
                    >
                      <div className="form-wrap form-wrap-validation">
                        <select
                          className="form-input select-filter"
                          data-style="modern"
                          data-placeholder="Choose Location"
                          data-minimum-results-for-search="Infinity"
                          data-constraints="@Required"
                        >
                          <option label="placeholder"></option>
                          <option value="2">Alaska</option>
                          <option value="3">Arizona</option>
                          <option value="4">Arkansas</option>
                          <option value="5">California</option>
                          <option value="6">Colorado</option>
                          <option value="7">Connecticut</option>
                          <option value="8">Delaware</option>
                          <option value="9">Florida</option>
                        </select>
                        <span className="select-arrow"></span>
                      </div>
                      <div className="form-wrap form-wrap-validation">
                        <select
                          className="form-input select-filter"
                          data-style="modern"
                          data-placeholder="Property Status"
                          data-minimum-results-for-search="Infinity"
                          data-constraints="@Required"
                        >
                          <option label="placeholder"></option>
                          <option value="2">Low</option>
                          <option value="3">Middle</option>
                          <option value="4">Primary</option>
                        </select>
                        <span className="select-arrow"></span>
                      </div>
                      <div className="form-wrap form-wrap-validation">
                        <select
                          className="form-input select-filter"
                          data-style="modern"
                          data-placeholder="Property Type"
                          data-minimum-results-for-search="Infinity"
                          data-constraints="@Required"
                        >
                          <option label="placeholder"></option>
                          <option value="2">Low</option>
                          <option value="3">Middle</option>
                          <option value="4">Primary</option>
                        </select>
                        <span className="select-arrow"></span>
                      </div>
                      <div className="form-wrap-group">
                        <div className="form-wrap form-wrap-validation">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Min Price"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="2">100 $</option>
                            <option value="3">200 $</option>
                            <option value="4">300 $</option>
                          </select>
                          <span className="select-arrow"></span>
                        </div>
                        <div className="form-wrap form-wrap-validation">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Max Price"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="2">1000 $</option>
                            <option value="3">2000 $</option>
                            <option value="4">3000 $</option>
                          </select>
                          <span className="select-arrow"></span>
                        </div>
                      </div>
                      <div className="form-wrap-group">
                        <div className="form-wrap form-wrap-validation">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Min Area"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="2">100 Sq Ft</option>
                            <option value="3">200 Sq Ft</option>
                            <option value="4">300 Sq Ft</option>
                          </select>
                          <span className="select-arrow"></span>
                        </div>
                        <div className="form-wrap form-wrap-validation">
                          <select
                            className="form-input select-filter"
                            data-style="modern"
                            data-placeholder="Max Area"
                            data-minimum-results-for-search="Infinity"
                            data-constraints="@Required"
                          >
                            <option label="placeholder"></option>
                            <option value="2">1000 Sq Ft</option>
                            <option value="3">2000 Sq Ft</option>
                            <option value="4">3000 Sq Ft</option>
                          </select>
                          <span className="select-arrow"></span>
                        </div>
                      </div>
                      <div className="form-button">
                        <button className="button button-block button-primary" type="submit">
                          Search
                        </button>
                      </div>
                    </form>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>
    </>
  );
}
