import formatSlug from "@/utils/payload/formatSlug";
import type { CollectionConfig } from "payload";

export const Properties: CollectionConfig = {
  slug: "properties",
  labels: { plural: "Properties", singular: "Property" },
  fields: [
    {
      name: "propertyType",
      label: "Type",
      type: "select",
      options: [
        { label: "Rent", value: "rent" },
        { label: "Sell", value: "sell" },
      ],
      required: true,
    },
    {
      name: "name",
      type: "text",
      required: true,
    },
    {
      name: "slug",
      type: "text",
      admin: {
        position: "sidebar",
      },
      hooks: {
        beforeValidate: [formatSlug("name")],
      },
    },
    {
      name: "images",
      type: "upload",
      relationTo: "media",
      hasMany: true,
      minRows: 1,
      required: true,
    },
    {
      name: "aboutGroup",
      label: "About",
      type: "group",
      fields: [
        {
          name: "description",
          type: "richText",
          required: true,
        },
        {
          name: "area",
          label: "Area (Sqft)",
          type: "text",
          required: true,
        },
        {
          name: "bathrooms_count",
          label: "Total Bathrooms",
          type: "text",
          required: true,
        },
        {
          name: "bedrooms_count",
          label: "Total Bedrooms",
          type: "text",
          required: true,
        },
      ],
    },
    {
      name: "addressGroup",
      label: "Address",
      type: "group",
      fields: [
        {
          name: "country_code",
          label: "Country",
          type: "select",
          options: [
            {
              label: "United States",
              value: "US",
            },
          ],
          required: true,
          // admin: {
          //   components: {
          //     Field: {
          //       path: "/components/payload-custom/InputCountry",
          //     },
          //   },
          // },
        },
        {
          name: "state_code",
          label: "State",
          type: "select",
          options: [
            {
              label: "Washington",
              value: "WA",
            },
          ],
          required: true,
        },
        {
          name: "city_code",
          label: "City",
          type: "select",
          options: [
            {
              label: "Davenport",
              value: "Davenport",
            },
          ],
          required: true,
        },
        {
          name: "zip_code",
          label: "Zip",
          type: "text",
          required: true,
        },
        {
          name: "address",
          label: "Address",
          type: "text",
          required: true,
        },
      ],
    },
    {
      name: "features",
      type: "relationship",
      relationTo: "propertyFeatures",
      required: true,
      hasMany: true,
      minRows: 1,
    },
    {
      name: "base_price",
      label: "Base Price",
      type: "number",
      required: true,
    },
    {
      name: "additional_price",
      label: "Additional Price",
      type: "array",
      fields: [
        {
          name: "name",
          type: "text",
          required: true,
        },
        {
          name: "price",
          type: "number",
          required: true,
        },
      ],
    },
    {
      name: "embed_map_url",
      label: "Embed Map URL",
      type: "text",
    },
  ],
  admin: {
    hideAPIURL: true,
    group: "Properties",
    useAsTitle: "name",
  },
};
