import { CardPropertyData } from "@/schema/property";
import { formatCurrency } from "@/utils/general";
import Image from "next/image";
import Link from "next/link";

type CardPropertyProps = {
  data: CardPropertyData;
};

export default function CardProperty({ data }: CardPropertyProps) {
  return (
    <>
      <div>
        <article className="product-classic">
          <div className="product-classic-media">
            <div
              className="owl-carousel"
              data-items="1"
              data-nav="true"
              data-stage-padding="0"
              data-loop="false"
              data-margin="0"
              data-mouse-drag="false"
            >
              {Array.isArray(data.images) &&
                data.images.map((img, idx) => (
                  <Image key={idx} src={img.url} alt={img.alt ?? ""} width="480" height="287" />
                ))}
            </div>
            <div className="product-classic-price bg-colorPriceTag/80!">
              <span>
                {formatCurrency(data.price)}
                {data.propertyType === "rent" && `/mo`}
              </span>
            </div>
          </div>
          <h4 className="product-classic-title">
            <Link href="/listings-for-rent/slug">{data.title}</Link>
          </h4>
          <div className="product-classic-divider"></div>
          <ul className="product-classic-list">
            <li>
              <span className="icon mdi mdi-vector-square"></span>
              <span>{data.area} Sq Ft</span>
            </li>
            {data.bathrooms_count && (
              <li>
                <span className="icon hotel-icon-10"></span>
                <span>{data.bathrooms_count} Bathrooms</span>
              </li>
            )}
            {data.bedrooms_count && (
              <li>
                <span className="icon hotel-icon-05"></span>
                <span>{data.bedrooms_count} Bedrooms</span>
              </li>
            )}
          </ul>
        </article>
      </div>
    </>
  );
}
